@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -29,11 +29,11 @@ class ImportBlogiloJob : public AbstractImportExportJob
     Q_OBJECT
 public:
     explicit ImportBlogiloJob(QObject *parent, Utils::StoredTypes typeSelected, ArchiveStorage *archiveStorage, int numberOfStep);
-    ~ImportBlogiloJob();
+    ~ImportBlogiloJob() override;
 
     void start() override;
 
-private Q_SLOTS:
+private:
     void slotNextStep() override;
 
 private:
