@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -30,11 +30,11 @@ class ImportCalendarJob : public AbstractImportExportJob
     Q_OBJECT
 public:
     explicit ImportCalendarJob(QObject *parent, Utils::StoredTypes typeSelected, ArchiveStorage *archiveStorage, int numberOfStep);
-    ~ImportCalendarJob();
+    ~ImportCalendarJob() override;
 
     void start() override;
 
-protected Q_SLOTS:
+protected:
     void slotNextStep() override;
 
 private:
